=======
History
=======

0.1.0 (2019-08-15)
------------------

* First release on PyPI.

0.1.1 (2019-09-21)
------------------

0.1.2 (2020-01-20)
------------------
1. Fixed bugs about dead end and single pipe.
2. Added plot and change detection methods.

0.2.0 (2020-4-23)
-------------------
1. Added quasi-steady and unsteady friction model.
2. Added open and closed surge tanks.
3. Added demand-pulse simulation.
4. Updated docs.

0.2.1 (2020-09-09)
-------------------
1. Fixed minor bugs about valve default settings.
2. Updated documentation.
3. Updated WNTR compatibility.

0.2.2 (2020-09-24)
-------------------
1. Updated WNTR compatibility.